@@ -17,6 +17,7 @@
 #[cfg(feature = "alloc")]
 extern crate alloc;
 
+mod is_covariant;
 mod macro_impls;
 pub mod trait_hack;
 mod yoke;
@@ -29,6 +30,7 @@ mod serde;
 #[cfg(feature = "derive")]
 pub use yoke_derive::{Yokeable, ZeroCopyFrom};
 
+pub use crate::is_covariant::IsCovariant;
 pub use crate::yoke::{CloneableCart, Yoke};
 pub use crate::yokeable::Yokeable;
 pub use crate::zero_copy_from::ZeroCopyFrom;
